==> koffice-trinity-14.0.13.tar.xz: koffice-trinity-14.0.13/kounavail/kounavail.cpp <==
/* This file is part of the KDE project
   Copyright (C) 2001 David Faure <faure@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#include "kounavail.h"

#include <tqpainter.h>
#include <tqiconset.h>
#include <tdeaction.h>
#include <kinstance.h>
#include <kstdaction.h>
#include <tdelocale.h>
#include <tdeaboutdata.h>
#include <kdebug.h>
#include <tdeglobalsettings.h>
#include <tqapplication.h>

KoUnavailPart::KoUnavailPart( TQWidget *parentWidget, const char *widgetName, TQObject* parent, const char* name )
    : KoDocument( parentWidget, widgetName, parent, name, false /*singleViewMode*/ )
{
    setReadWrite( false );
}

KoView* KoUnavailPart::createViewInstance( TQWidget* parent, const char* name )
{
    return new KoUnavailView( this, parent, name );
}

bool KoUnavailPart::loadOasis( const TQDomDocument& doc, KoOasisStyles&, const TQDomDocument&, KoStore* )
{
    m_doc = doc;
    return true;
}

bool KoUnavailPart::loadXML( TQIODevice *, const TQDomDocument &doc )
{
    // Simply keep a copy of the whole document ;)
    m_doc = doc;
    return true;
}

bool KoUnavailPart::saveFile()
{
    kdDebug() << "KoUnavailPart::saveFile m_url=" << m_url.prettyURL() << endl;
    // This is called if the part points to an external file
    // In that case we have nothing to save, the file was unavailable !
    return true;
}

TQDomDocument KoUnavailPart::saveXML()
{
    kdDebug() << "KoUnavailPart::saveXML" << endl;
    return m_doc;
}


bool KoUnavailPart::saveOasis(KoStore*, KoXmlWriter*)
{
    // TODO
    return false;
}

void KoUnavailPart::setMimeType( const TQCString& mime )
{
    kdDebug() << "KoUnavailPart::setMimeType " << mime << endl;
    m_mimetype = mime;
}

void KoUnavailPart::paintContent( TQPainter& painter, const TQRect& rect, bool /*transparent*/,
                                double /*zoomX*/, double /*zoomY*/ )
{
    painter.save();
    painter.setPen( TQApplication::palette().color( TQPalette::Active, TQColorGroup::Text ) );
    // Need to draw only the document rectangle described in the parameter rect.
    int left = rect.left() / 20;
    int right = rect.right() / 20 + 1;
    int top = rect.top() / 20;
    int bottom = rect.bottom() / 20 + 1;

    for( int x = left; x < right; ++x )
        painter.drawLine( x * 20, top * 20, x * 20, bottom * 20 );
    for( int y = left; y < right; ++y )
        painter.drawLine( left * 20, y * 20, right * 20, y * 20 );

    TQFont defaultFont = TDEGlobalSettings::generalFont();
    defaultFont.setPointSize( 16 ); // ###
    painter.setFont( defaultFont );
    //painter.drawText( 20, 20, m_reason );
    painter.drawText( rect, TQt::AlignCenter | TQt::WordBreak, m_reason );
    painter.restore();
}

KoUnavailView::KoUnavailView( KoUnavailPart* part, TQWidget* parent, const char* name )
    : KoView( part, parent, name )
{
    setInstance( KoUnavailFactory::global() );
    //setXMLFile( "kounavail.rc" );
}

void KoUnavailView::paintEvent( TQPaintEvent* ev )
{
    TQPainter painter;
    painter.begin( this );

    // ### TODO: Scaling

    // Let the document do the drawing
    koDocument()->paintEverything( painter, ev->rect(), FALSE, this );

    painter.end();
}

K_EXPORT_COMPONENT_FACTORY( libkounavailpart, KoUnavailFactory )

TDEInstance* KoUnavailFactory::s_global = 0L;
TDEAboutData* KoUnavailFactory::s_aboutData = 0L;

KoUnavailFactory::KoUnavailFactory( TQObject* parent, const char* name )
    : KoFactory( parent, name )
{
    global();
}

KoUnavailFactory::~KoUnavailFactory()
{
    delete s_aboutData;
    s_aboutData = 0L;
    delete s_global;
    s_global = 0L;
}

KParts::Part* KoUnavailFactory::createPartObject( TQWidget *parentWidget, const char *widgetName, TQObject* parent, const char* name, const char*, const TQStringList & )
{
    return new KoUnavailPart( parentWidget, widgetName, parent, name );
}

TDEAboutData* KoUnavailFactory::aboutData()
{
    if ( !s_aboutData )
    {
        static const char* description=I18N_NOOP("KoUnavail KOffice Program");
        static const char* version="0.1";
        s_aboutData=new TDEAboutData( "kounavail", I18N_NOOP("KoUnavail"),
                                    version, description, TDEAboutData::License_LGPL,
                                    "(c) 2001, David Faure");
        s_aboutData->addAuthor("David Faure",0, "faure@kde.org");
    }
    return s_aboutData;
}

TDEInstance* KoUnavailFactory::global()
{
    if ( !s_global )
    {
        s_global = new TDEInstance( aboutData() );
        // Tell the iconloader about share/apps/koffice/icons
        //s_global->iconLoader()->addAppDir("koffice");
    }
    return s_global;
}

#include "kounavail.moc"

==> koffice-trinity-14.1.4.tar.xz: koffice-trinity-14.1.4/kounavail/kounavail.cpp <==
/* This file is part of the KDE project
   Copyright (C) 2001 David Faure <faure@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#include "kounavail.h"

#include <tqpainter.h>
#include <tqiconset.h>
#include <tdeaction.h>
#include <kinstance.h>
#include <kstdaction.h>
#include <tdelocale.h>
#include <tdeaboutdata.h>
#include <kdebug.h>
#include <tdeglobalsettings.h>
#include <tqapplication.h>

KoUnavailPart::KoUnavailPart( TQWidget *parentWidget, const char *widgetName, TQObject* parent, const char* name )
    : KoDocument( parentWidget, widgetName, parent, name, false /*singleViewMode*/ )
{
    setReadWrite( false );
}

KoView* KoUnavailPart::createViewInstance( TQWidget* parent, const char* name )
{
    return new KoUnavailView( this, parent, name );
}

bool KoUnavailPart::loadOasis( const TQDomDocument& doc, KoOasisStyles&, const TQDomDocument&, KoStore* )
{
    m_doc = doc;
    return true;
}

bool KoUnavailPart::loadXML( TQIODevice *, const TQDomDocument &doc )
{
    // Simply keep a copy of the whole document ;)
    m_doc = doc;
    return true;
}

bool KoUnavailPart::saveFile()
{
    kdDebug() << "KoUnavailPart::saveFile m_url=" << m_url.prettyURL() << endl;
    // This is called if the part points to an external file
    // In that case we have nothing to save, the file was unavailable !
    return true;
}

TQDomDocument KoUnavailPart::saveXML()
{
    kdDebug() << "KoUnavailPart::saveXML" << endl;
    return m_doc;
}


bool KoUnavailPart::saveOasis(KoStore*, KoXmlWriter*)
{
    // TODO
    return false;
}

void KoUnavailPart::setMimeType( const TQCString& mime )
{
    kdDebug() << "KoUnavailPart::setMimeType " << mime << endl;
    m_mimetype = mime;
}

void KoUnavailPart::paintContent( TQPainter& painter, const TQRect& rect, bool /*transparent*/,
                                double /*zoomX*/, double /*zoomY*/ )
{
    painter.save();
    painter.setPen( TQApplication::palette().color( TQPalette::Active, TQColorGroup::Text ) );
    // Need to draw only the document rectangle described in the parameter rect.
    int left = rect.left() / 20;
    int right = rect.right() / 20 + 1;
    int top = rect.top() / 20;
    int bottom = rect.bottom() / 20 + 1;

    for( int x = left; x < right; ++x )
        painter.drawLine( x * 20, top * 20, x * 20, bottom * 20 );
    for( int y = left; y < right; ++y )
        painter.drawLine( left * 20, y * 20, right * 20, y * 20 );

    TQFont defaultFont = TDEGlobalSettings::generalFont();
    defaultFont.setPointSize( 16 ); // ###
    painter.setFont( defaultFont );
    //painter.drawText( 20, 20, m_reason );
    painter.drawText( rect, TQt::AlignCenter | TQt::WordBreak, m_reason );
    painter.restore();
}

KoUnavailView::KoUnavailView( KoUnavailPart* part, TQWidget* parent, const char* name )
    : KoView( part, parent, name )
{
    setInstance( KoUnavailFactory::global() );
    //setXMLFile( "kounavail.rc" );
}

void KoUnavailView::paintEvent( TQPaintEvent* ev )
{
    TQPainter painter;
    painter.begin( this );

    // ### TODO: Scaling

    // Let the document do the drawing
    koDocument()->paintEverything( painter, ev->rect(), false, this );

    painter.end();
}

K_EXPORT_COMPONENT_FACTORY( libkounavailpart, KoUnavailFactory )

TDEInstance* KoUnavailFactory::s_global = 0L;
TDEAboutData* KoUnavailFactory::s_aboutData = 0L;

KoUnavailFactory::KoUnavailFactory( TQObject* parent, const char* name )
    : KoFactory( parent, name )
{
    global();
}

KoUnavailFactory::~KoUnavailFactory()
{
    delete s_aboutData;
    s_aboutData = 0L;
    delete s_global;
    s_global = 0L;
}

KParts::Part* KoUnavailFactory::createPartObject( TQWidget *parentWidget, const char *widgetName, TQObject* parent, const char* name, const char*, const TQStringList & )
{
    return new KoUnavailPart( parentWidget, widgetName, parent, name );
}

TDEAboutData* KoUnavailFactory::aboutData()
{
    if ( !s_aboutData )
    {
        static const char* description=I18N_NOOP("KoUnavail KOffice Program");
        static const char* version="0.1";
        s_aboutData=new TDEAboutData( "kounavail", I18N_NOOP("KoUnavail"),
                                    version, description, TDEAboutData::License_LGPL,
                                    "(c) 2001, David Faure");
        s_aboutData->addAuthor("David Faure",0, "faure@kde.org");
    }
    return s_aboutData;
}

TDEInstance* KoUnavailFactory::global()
{
    if ( !s_global )
    {
        s_global = new TDEInstance( aboutData() );
        // Tell the iconloader about share/apps/koffice/icons
        //s_global->iconLoader()->addAppDir("koffice");
    }
    return s_global;
}

#include "kounavail.moc"
